Index: sansview/perspectives/fitting/fitpage1D.py
===================================================================
--- sansview/perspectives/fitting/fitpage1D.py	(revision 6b44403cab92de3307a7e6c39bed9f4b6f967a54)
+++ sansview/perspectives/fitting/fitpage1D.py	(revision 94999eb62566bdc5b297431509bc8734a75252f5)
@@ -137,5 +137,8 @@
         #------------------ sizer 4  draw------------------------   
         self.modelbox = wx.ComboBox(self, -1)
-        
+        self.tcChi    =  wx.StaticText(self, -1, str(0), style=wx.ALIGN_LEFT)
+        self.tcChi.Hide()
+        self.text1_1 = wx.StaticText(self, -1, 'Chi2/dof', style=wx.ALIGN_LEFT)
+        self.text1_1.Hide()
         #filling sizer2
         ix = 0
@@ -145,5 +148,9 @@
         ix += 1
         self.sizer4.Add(self.modelbox,(iy,ix),(1,1),  wx.EXPAND|wx.ADJUST_MINSIZE, 0)
-        
+        ix += 1
+        self.sizer4.Add(self.text1_1,(iy,ix),(1,1),\
+                   wx.LEFT|wx.EXPAND|wx.ADJUST_MINSIZE, 15)
+        ix += 1
+        self.sizer4.Add(self.tcChi,(iy,ix),(1,1), wx.LEFT|wx.EXPAND|wx.ADJUST_MINSIZE, 0)
         #----------sizer6-------------------------------------------------
         self.disable_disp = wx.RadioButton(self, -1, 'No', (10, 10), style=wx.RB_GROUP)
@@ -165,8 +172,5 @@
         
         #---------sizer 9 draw----------------------------------------
-        self.tcChi    =  wx.StaticText(self, -1, str(0), style=wx.ALIGN_LEFT)
-        self.tcChi.Hide()
-        self.text1_1 = wx.StaticText(self, -1, 'Chi2/dof', style=wx.ALIGN_LEFT)
-        self.text1_1.Hide()
+        
         
         id = wx.NewId()
@@ -235,11 +239,6 @@
         ix += 1
         self.sizer9.Add(self.npts,(iy,ix),(1,1), wx.LEFT|wx.EXPAND|wx.ADJUST_MINSIZE, 0)
-        ix = 0
-        iy += 1
-        self.sizer9.Add(self.text1_1,(iy,ix),(1,1),\
-                   wx.LEFT|wx.EXPAND|wx.ADJUST_MINSIZE, 15)
-        ix += 1
-        self.sizer9.Add(self.tcChi,(iy,ix),(1,1), wx.LEFT|wx.EXPAND|wx.ADJUST_MINSIZE, 0)
-        ix +=2
+        
+        ix += 1
         self.sizer9.Add(self.btFit,(iy,ix),(1,1), wx.LEFT|wx.EXPAND|wx.ADJUST_MINSIZE, 0)
         ix =0
@@ -322,4 +321,5 @@
         
         flag=self.checkFitRange()
+        print "flag", flag
         if flag== True:
             try:
@@ -330,4 +330,5 @@
                     self.qmin_x = float(self.qmin.GetValue())
                     self.qmax_x = float(self.qmax.GetValue())
+                    print "self.qmin_x, self.qmax_x",self.qmin_x,self.qmax_x
                     x,y,dy = [numpy.asarray(v) for v in (self.data.x,self.data.y,self.data.dy)]
                     if self.qmin_x==None and self.qmax_x==None: 
@@ -338,5 +339,4 @@
                         fx = numpy.asarray([self.model.run(item)for item in x[idx ]])
                         res= (y[idx] - fx)/dy[idx]  
-                    
                    
                     sum=0
@@ -372,6 +372,6 @@
                     evt = ModelEventbox(model=self.model,name=name)
                     wx.PostEvent(self.event_owner, evt)
-                    #self.model= item()
-                    #self.set_panel(self.model)
+                    self.text1_1.Show()
+                    self.tcChi.Show()
                 except:
                     raise #ValueError,"model.name is not equal to model class name"
@@ -583,32 +583,5 @@
              set to true or false all checkBox given the main checkbox value cb1
         """
-        self.param_toFit=[]
-        if  self.parameters !=[]:
-            if  self.cb1.GetValue()==True:
-                for item in self.parameters:
-                    item[0].SetValue(True)
-                    list= [item[0],item[1],item[2],item[3]]
-                    self.param_toFit.append(list )
-                if len(self.fittable_param)>0:
-                    for item in self.fittable_param:
-                        item[0].SetValue(True)
-                        list= [item[0],item[1],item[2],item[3]]
-                        self.param_toFit.append(list )
-               
-                if not (len(self.param_toFit ) >0):
-                    self.qmin.Disable()
-                    self.qmax.Disable()
-                else:
-                    self.qmin.Enable()
-                    self.qmax.Enable()
-            else:
-                for item in self.parameters:
-                    item[0].SetValue(False)
-                for item in self.fittable_param:
-                    item[0].SetValue(False)
-                self.param_toFit=[]
-              
-                self.qmin.Disable()
-                self.qmax.Disable()
+        self.select_all_param_helper()
                 
                 
Index: sansview/perspectives/fitting/fitting.py
===================================================================
--- sansview/perspectives/fitting/fitting.py	(revision 26bf293e779f5260e7b862a7c8a9774edc7f78ba)
+++ sansview/perspectives/fitting/fitting.py	(revision 94999eb62566bdc5b297431509bc8734a75252f5)
@@ -231,5 +231,5 @@
              @note: expecting park used for fit.
         """  
-        sim_page=self.fit_panel.get_page(0)
+        sim_page=self.fit_panel.get_page(1)
         for page, value in self.page_finder.iteritems():
             if page != sim_page:
@@ -517,5 +517,5 @@
         name = evt.name
         
-        sim_page=self.fit_panel.GetPage(0)
+        sim_page=self.fit_panel.GetPage(1)
         current_pg = self.fit_panel.get_current_page() 
         if current_pg != sim_page:
@@ -639,5 +639,5 @@
                         for j in range(len(data.x_bins)):
                             if data.x_bins[i]>= qmin and data.x_bins[i]<= qmax:
-                                theory.data[j][i]=model.runXY([data.x_bins[j],data.y_bins[i]])
+                                theory.data[i][j]=model.runXY([data.x_bins[j],data.y_bins[i]])
                
                 #print "fitting : plot_helper:", theory.image
Index: sansview/perspectives/fitting/modelpage.py
===================================================================
--- sansview/perspectives/fitting/modelpage.py	(revision 6b44403cab92de3307a7e6c39bed9f4b6f967a54)
+++ sansview/perspectives/fitting/modelpage.py	(revision 94999eb62566bdc5b297431509bc8734a75252f5)
@@ -264,4 +264,7 @@
                 return 
             else:
+                if self.data !=None: # allow to recognize data panel from model panel
+                    self.cb1.SetValue(False)
+                    self.select_all_param_helper()
                 self.fittable_param=[]
                 self.fixed_param=[]
@@ -274,4 +277,7 @@
                 self.parent.GetSizer().Layout()   
         else:
+            if self.data !=None:
+                if self.cb1.GetValue():
+                    self.select_all_param_helper()
             self.fittable_param=[]        
             self.fixed_param=[]
@@ -448,4 +454,5 @@
         """
         print "set_panel", model
+        
         self.sizer5.Clear(True)
         self.parameters = []
@@ -615,5 +622,5 @@
                         self.sizer8.Add(ctl2, (iy,ix),(1,1), wx.EXPAND|wx.ADJUST_MINSIZE, 0)
                         ctl2.Hide()
-                        self.fittable_param=[cb,ctl1,text2,ctl2]
+                        self.fittable_param.append([cb,ctl1,text2,ctl2])
                        
                         
@@ -725,4 +732,35 @@
     def select_all_param(self,event): 
         pass
-        
-       
+    def select_all_param_helper(self):
+        """
+             Allows selecting or delecting button
+        """
+        self.param_toFit=[]
+        if  self.parameters !=[]:
+            if  self.cb1.GetValue()==True:
+                for item in self.parameters:
+                    item[0].SetValue(True)
+                    list= [item[0],item[1],item[2],item[3]]
+                    self.param_toFit.append(list )
+                if len(self.fittable_param)>0:
+                    for item in self.fittable_param:
+                        item[0].SetValue(True)
+                        list= [item[0],item[1],item[2],item[3]]
+                        self.param_toFit.append(list )
+               
+                if not (len(self.param_toFit ) >0):
+                    self.qmin.Disable()
+                    self.qmax.Disable()
+                else:
+                    self.qmin.Enable()
+                    self.qmax.Enable()
+            else:
+                for item in self.parameters:
+                    item[0].SetValue(False)
+                for item in self.fittable_param:
+                    item[0].SetValue(False)
+                self.param_toFit=[]
+              
+                self.qmin.Disable()
+                self.qmax.Disable()
+       

Index: sansview/perspectives/fitting/fitpanel.py
===================================================================
--- sansview/perspectives/fitting/fitpanel.py	(revision 6b44403cab92de3307a7e6c39bed9f4b6f967a54)
+++ sansview/perspectives/fitting/fitpanel.py	(revision 94999eb62566bdc5b297431509bc8734a75252f5)
@@ -23,5 +23,7 @@
     def __init__(self, parent, *args, **kwargs):
         
-        wx.aui.AuiNotebook.__init__(self,parent,-1, style=wx.aui.AUI_NB_SCROLL_BUTTONS )
+        #wx.aui.AuiNotebook.__init__(self,parent,-1, style=wx.aui.AUI_NB_SCROLL_BUTTONS )
+        wx.aui.AuiNotebook.__init__(self,parent,-1, style=wx.aui.AUI_NB_DEFAULT_STYLE  )
+        
         
         self.manager=None
@@ -31,9 +33,14 @@
         pageClosedEvent = wx.aui.EVT_AUINOTEBOOK_PAGE_CLOSE
         self.Bind(wx.aui.EVT_AUINOTEBOOK_PAGE_CLOSE, self.onClosePage)
-
-        #Creating an initial page for simultaneous fitting
+        #Creating the default page --welcomed page
+        from sans.guiframe.welcome_panel import PanelAbout
+        self.about_page = PanelAbout(self, -1)
+        self.AddPage(self.about_page,"welcome!")
+        #self.about_page.Disable()
+        #Creating a page for simultaneous fitting
         from simfitpage import SimultaneousFitPage
         self.sim_page = SimultaneousFitPage(self, -1)
         self.AddPage(self.sim_page,"Simultaneous Fit")
+        
         
 
@@ -105,4 +112,5 @@
             else:
            """
+            #self.about_page.Disable()
             from fitpage1D import FitPage1D
             panel = FitPage1D(self,data, -1)